Skip to contents

Add a bullet or numbered list produced by block_list_items() into an rdocx object.

Usage

body_add_list(x, items, pos = "after")

Arguments

x

an rdocx object

items

a block_list_items() object.

pos

where to add the new element relative to the cursor, one of "after", "before", "on".

Examples

library(officer)

items <- block_list_items(
  list_item(fpar(ftext("Item 1", fp_text(color = "red"))), level = 1),
  list_item(fpar("Sub-item"), level = 2),
  list_item(fpar("Item 2"), level = 1),
  list_type = "bullet"
)

doc <- read_docx()
doc <- body_add_list(doc, items = items)
print(doc, target = tempfile(fileext = ".docx"))