append fpar (a formatted paragraph) in a placeholder
The function let you add a new formatted paragraph (fpar)
to an existing content in an existing shape, existing paragraphs
will be preserved.
ph_add_fpar(
x,
value,
type = "body",
id = 1,
id_chr = NULL,
ph_label = NULL,
level = 1,
par_default = TRUE
)an rpptx object
fpar object
placeholder type
placeholder index (integer) for a duplicated type. This is to be used when a placeholder
type is not unique in the layout of the current slide, e.g. two placeholders with type 'body'. To
add onto the first, use id = 1 and id = 2 for the second one.
Values can be read from slide_summary.
deprecated.
label associated to the placeholder. Use column
ph_label of result returned by slide_summary.
paragraph level
specify if the default paragraph formatting should be used.
If your goal is to add formatted text in a new shape, use ph_with
with a block_list instead of this function.