add an unordered list of text
into an rpptx object. Each text is associated with
a hierarchy level.
This function will be deprecated in favor of ph_with
in the next release.
ph_with_ul(x, type = "body", index = 1, str_list = character(0),
level_list = integer(0), style = NULL, location = NULL)an pptx object
placeholder type (i.e. 'body', 'title')
placeholder index (integer). This is to be used when a placeholder type
is not unique in the current slide, e.g. two placeholders with type 'body', the first
one will be added with index 1 and the second one with index 2.
It is recommanded to use argument location instead of type and
index.
list of strings to be included in the object
list of levels for hierarchy structure
text style, a fp_text object list or a
single fp_text objects. Use fp_text(font.size = 0, ...) to
inherit from default sizes of the presentation.
a placeholder location object. This is a convenient
argument that can replace usage of arguments type and index.
See ph_location_type, ph_location, ph_location_label,
ph_location_left, ph_location_right, ph_location_fullsize.