View source: R/ooxml_run_objects.R
| run_word_field | R Documentation |
Create a 'Word' computed field.
run_word_field(field, prop = NULL)
field |
Value for a "Word Computed Field" as a string. |
prop |
formatting text properties returned by fp_text. |
You can use this function in conjunction with fpar to create paragraphs consisting of differently formatted text parts. You can also use this function as an r chunk in an R Markdown document made with package officedown.
Other run functions for reporting:
external_img(),
floating_external_img(),
ftext(),
hyperlink_ftext(),
run_autonum(),
run_bookmark(),
run_columnbreak(),
run_comment(),
run_footnote(),
run_footnoteref(),
run_linebreak(),
run_pagebreak(),
run_reference(),
run_tab(),
run_wordtext()
Other Word computed fields:
run_autonum(),
run_reference()
run_word_field(field = "PAGE \\* MERGEFORMAT")
run_word_field(field = "Date \\@ \"MMMM d yyyy\"")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.