Return the sheet names of an rxlsx object, in the
order they appear in the workbook.
Arguments
- x
an rxlsx object (created by
read_xlsx()).
Return the sheet names of an rxlsx object, in the
order they appear in the workbook.
an rxlsx object (created by read_xlsx()).