body_add_list: Add a list of items into a 'Word' document

View source: R/docx_add.R

body_add_listR Documentation

Add a list of items into a 'Word' document

Description

Add a bullet or numbered list produced by block_list_items() into an rdocx object.

Usage

body_add_list(x, items, pos = "after")

Arguments

x

an rdocx object

items

a block_list_items() object.

pos

where to add the new element relative to the cursor, one of "after", "before", "on".

See Also

Other functions for adding content: body_add_blocks(), body_add_break(), body_add_caption(), body_add_docx(), body_add_fpar(), body_add_gg(), body_add_img(), body_add_par(), body_add_plot(), body_add_table(), body_add_toc(), body_append_start_context(), body_import_docx()

Examples

library(officer)

items <- block_list_items(
  list_item(fpar(ftext("Item 1", fp_text(color = "red"))), level = 1),
  list_item(fpar("Sub-item"), level = 2),
  list_item(fpar("Item 2"), level = 1),
  list_type = "bullet"
)

doc <- read_docx()
doc <- body_add_list(doc, items = items)
print(doc, target = tempfile(fileext = ".docx"))

officer documentation built on April 24, 2026, 5:06 p.m.