Learn R Programming

officer (version 0.7.6)

docx_show_chunk: Show underlying text tag structure

Description

Show the structure of text tags at the current cursor. This is most useful when trying to troubleshoot search-and-replace functionality using body_replace_all_text().

Usage

docx_show_chunk(x)

Arguments

x

a docx device

See Also

body_replace_all_text()