powered by
Show the structure of text tags at the current cursor. This is most useful when trying to troubleshoot search-and-replace functionality using body_replace_all_text().
body_replace_all_text()
docx_show_chunk(x)
a docx device