Learn R Programming

officer (version 0.7.6)

run_word_field: 'Word' computed field

Description

Create a 'Word' computed field.

Usage

run_word_field(field, prop = NULL)

Arguments

field

Value for a "Word Computed Field" as a string.

prop

formatting text properties returned by fp_text.

usage

You can use this function in conjunction with fpar to create paragraphs consisting of differently formatted text parts. You can also use this function as an r chunk in an R Markdown document made with package officedown.

See Also

Other run functions for reporting: external_img(), floating_external_img(), ftext(), hyperlink_ftext(), run_autonum(), run_bookmark(), run_columnbreak(), run_comment(), run_footnote(), run_footnoteref(), run_linebreak(), run_pagebreak(), run_reference(), run_tab(), run_wordtext()

Other Word computed fields: run_autonum(), run_reference()

Examples

Run this code
run_word_field(field = "PAGE  \\* MERGEFORMAT")
run_word_field(field = "Date \\@ \"MMMM d yyyy\"")

Run the code above in your browser using DataLab